weblogolib.logomath.Gamma

Package weblogolib :: Module logomath :: Class Gamma |

# Class Gamma

source code

    object --+
             |
            Gamma

    The gamma probability distribution. (Not to be confused with the
    gamma function.)

Instance Methods
__init__(self, alpha, beta) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
mean(self) | source code
variance(self) | source code
sample(self) | source code
pdf(self, x) | source code
cdf(self, x) | source code
inverse_cdf(self, p) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods
from_shape_scale(cls, shape, scale) | source code
from_mean_variance(cls, mean, variance) | source code

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, alpha, beta) (Constructor) | source code
    x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Overrides: object.__init__ (inherited documentation)